@@ -8,42 +8,119 @@
 #include <qpopmenu.h>
 #include <qkeycode.h>
 #include <qapp.h>
+#include <qmsgbox.h>
+#include <qpixmap.h>
+
+/* XPM */
+static const char * p1_xpm[] = {
+"16 16 3 1",
+" 	c None",
+".	c #000000000000",
+"X	c #FFFFFFFF0000",
+"                ",
+"                ",
+"         ....   ",
+"        .XXXX.  ",
+" .............. ",
+" .XXXXXXXXXXXX. ",
+" .XXXXXXXXXXXX. ",
+" .XXXXXXXXXXXX. ",
+" .XXXXXXXXXXXX. ",
+" .XXXXXXXXXXXX. ",
+" .XXXXXXXXXXXX. ",
+" .XXXXXXXXXXXX. ",
+" .XXXXXXXXXXXX. ",
+" .XXXXXXXXXXXX. ",
+" .............. ",
+"                "};
+
+/* XPM */
+static const char * p2_xpm[] = {
+"16 16 3 1",
+" 	c None",
+".	c #000000000000",
+"X	c #FFFFFFFFFFFF",
+"                ",
+"   ......       ",
+"   .XXX.X.      ",
+"   .XXX.XX.     ",
+"   .XXX.XXX.    ",
+"   .XXX.....    ",
+"   .XXXXXXX.    ",
+"   .XXXXXXX.    ",
+"   .XXXXXXX.    ",
+"   .XXXXXXX.    ",
+"   .XXXXXXX.    ",
+"   .XXXXXXX.    ",
+"   .XXXXXXX.    ",
+"   .........    ",
+"                ",
+"                "};
+
+/* XPM */
+static const char * p3_xpm[] = {
+"16 16 3 1",
+" 	c None",
+".	c #000000000000",
+"X	c #FFFFFFFFFFFF",
+"                ",
+"                ",
+"   .........    ",
+"  ...........   ",
+"  ........ ..   ",
+"  ...........   ",
+"  ...........   ",
+"  ...........   ",
+"  ...........   ",
+"  ...XXXXX...   ",
+"  ...XXXXX...   ",
+"  ...XXXXX...   ",
+"  ...XXXXX...   ",
+"   .........    ",
+"                ",
+"                "};
+
 
 
 MenuExample::MenuExample( QWidget *parent, const char *name )
     : QWidget( parent, name )
 {
+    QPixmap p1( p1_xpm );
+    QPixmap p2( p2_xpm );
+    QPixmap p3( p3_xpm );
+
     QPopupMenu *print = new QPopupMenu;
     CHECK_PTR( print );
-    print->insertItem( "Print to printer", this, SLOT(printer()) );
-    print->insertItem( "Print to file", this, SLOT(file()) );
-    print->insertItem( "Print to fax", this, SLOT(fax()) );
+    print->insertItem( "&Print to printer", this, SLOT(printer()) );
+    print->insertItem( "Print to &file", this, SLOT(file()) );
+    print->insertItem( "Print to fa&x", this, SLOT(fax()) );
     print->insertSeparator();
-    print->insertItem( "Printer Setup", this, SLOT(printerSetup()) );
+    print->insertItem( "Printer &Setup", this, SLOT(printerSetup()) );
 
     QPopupMenu *file = new QPopupMenu();
     CHECK_PTR( file );
-    file->insertItem( "Open",  this, SLOT(open()), CTRL+Key_O );
-    file->insertItem( "Save", this, SLOT(save()), CTRL+Key_S );
-    file->insertItem( "Close", this, SLOT(closeDoc()), CTRL+Key_W );
+    file->insertItem( p1, "&Open",  this, SLOT(open()), CTRL+Key_O );
+    file->insertItem( p2, "&New", this, SLOT(news()), CTRL+Key_N );
+    file->insertItem( p3, "&Save", this, SLOT(save()), CTRL+Key_S );
+    file->insertItem( "&Close", this, SLOT(closeDoc()), CTRL+Key_W );
     file->insertSeparator();
-    file->insertItem( "Print", print, CTRL+Key_P );
+    file->insertItem( "&Print", print, CTRL+Key_P );
     file->insertSeparator();
-    file->insertItem( "Exit",  qApp, SLOT(quit()), CTRL+Key_Q );
+    file->insertItem( "E&xit",  qApp, SLOT(quit()), CTRL+Key_Q );
 
     QPopupMenu *edit = new QPopupMenu();
     CHECK_PTR( edit );
-    int undoID = edit->insertItem( "Undo", this, SLOT(undo()) );
-    int redoID = edit->insertItem( "Redo", this, SLOT(redo()) );
+    int undoID = edit->insertItem( "&Undo", this, SLOT(undo()) );
+    int redoID = edit->insertItem( "&Redo", this, SLOT(redo()) );
     edit->setItemEnabled( undoID, FALSE );
     edit->setItemEnabled( redoID, FALSE );
 
     options = new QPopupMenu();
     CHECK_PTR( options );
-    options->insertItem( "Normal Font", this, SLOT(normal()) );
+    options->insertItem( "&Normal Font", this, SLOT(normal()) );
     options->insertSeparator();
-    boldID = options->insertItem( "Bold", this, SLOT(bold()) );
-    underlineID = options->insertItem( "Underline", this, SLOT(underline()) );
+    boldID = options->insertItem( "&Bold", this, SLOT(bold()) );
+    underlineID = options->insertItem( "&Underline", this, SLOT(underline()) );
     isBold = FALSE;
     isUnderline = FALSE;
     options->setCheckable( TRUE );
@@ -51,7 +128,8 @@ MenuExample::MenuExample( QWidget *parent, const char *name )
 
     QPopupMenu *help = new QPopupMenu;
     CHECK_PTR( help );
-    help->insertItem( "About", this, SLOT(about()), CTRL+Key_H );
+    help->insertItem( "&About", this, SLOT(about()), CTRL+Key_H );
+    help->insertItem( "About &Qt", this, SLOT(aboutQt()) );
 
     menu = new QMenuBar( this );
     CHECK_PTR( menu );
@@ -60,6 +138,7 @@ MenuExample::MenuExample( QWidget *parent, const char *name )
     menu->insertItem( "&Options", options );
     menu->insertSeparator();
     menu->insertItem( "&Help", help );
+    menu->setSeparator( QMenuBar::InWindowsStyle );
 
     label = new QLabel( this );
     CHECK_PTR( label );
@@ -81,6 +160,11 @@ void MenuExample::open()
 }
 
 
+void MenuExample::news()
+{
+    emit explain( "File/New selected" );
+}
+
 void MenuExample::save()
 {
     emit explain( "File/Save selected" );
@@ -133,10 +217,18 @@ void MenuExample::underline()
 
 void MenuExample::about()
 {
-    emit explain( "Help/About selected" );
+    QMessageBox::about( this, "Qt Menu Example",
+			"This example demonstrates simple use of Qt menus.\n"
+			"You can cut and paste lines from it to your own\n"
+			"programs." );
 }
 
 
+void MenuExample::aboutQt()
+{
+    QMessageBox::aboutQt( this, "Qt Menu Example" );
+}
+
 
 void MenuExample::printer()
 {
