@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qimage.cpp,v 2.65 1997/09/25 15:25:06 hanord Exp $
+** $Id: qimage.cpp,v 2.65.2.1 1997/11/18 12:47:10 agulbra Exp $
 **
 ** Implementation of QImage and QImageIO classes
 **
@@ -7,7 +7,7 @@
 **
 ** Copyright (C) 1992-1997 Troll Tech AS.  All rights reserved.
 **
-** This file is part of the free edition of Qt 1.31.
+** This file is part of the free edition of Qt 1.33.
 **
 ** See the file LICENSE included in the distribution for the usage
 ** and distribution terms, or http://www.troll.no/qt/license.html.
@@ -34,7 +34,7 @@
 #include <stdlib.h>
 #include <ctype.h>
 
-RCSTAG("$Id: qimage.cpp,v 2.65 1997/09/25 15:25:06 hanord Exp $");
+RCSTAG("$Id: qimage.cpp,v 2.65.2.1 1997/11/18 12:47:10 agulbra Exp $");
 
 
 /*!
@@ -2480,7 +2480,7 @@ bool QImageIO::read()
     }
     iostat = 1;					// assume error
 
-    if ( h ) {
+    if ( h && h->read_image ) {
 	(*h->read_image)( this );
     } else {
 	// Format name, but no handler - must be an asychronous reader
@@ -2524,7 +2524,7 @@ bool QImageIO::write()
     if ( frmt.isEmpty() )
 	return FALSE;
     QImageHandler *h = get_image_handler( frmt );
-    if ( !h ) {
+    if ( !h || !h->write_image ) {
 #if defined(CHECK_RANGE)
 	warning( "QImageIO::write: No such image format handler: %s",
 		 format() );
