@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qwid_x11.cpp,v 2.69 1997/10/08 16:56:23 warwick Exp $
+** $Id: qwid_x11.cpp,v 2.70.2.3 1998/03/16 22:02:09 agulbra Exp $
 **
 ** Implementation of QWidget and QWindow classes for X11
 **
@@ -7,7 +7,7 @@
 **
 ** Copyright (C) 1992-1997 Troll Tech AS.  All rights reserved.
 **
-** This file is part of the free edition of Qt 1.31.
+** This file is part of the free edition of Qt 1.33.
 **
 ** See the file LICENSE included in the distribution for the usage
 ** and distribution terms, or http://www.troll.no/qt/license.html.
@@ -39,7 +39,7 @@ typedef char *XPointer;
 #undef  X11R4
 #endif
 
-RCSTAG("$Id: qwid_x11.cpp,v 2.69 1997/10/08 16:56:23 warwick Exp $");
+RCSTAG("$Id: qwid_x11.cpp,v 2.70.2.3 1998/03/16 22:02:09 agulbra Exp $");
 
 
 void qt_enter_modal( QWidget * );		// defined in qapp_x11.cpp
@@ -297,9 +297,9 @@ void QWidget::create( WId window, bool initializeWindow, bool destroyOldWindow)
 	frect.setRect( a.x, a.y, a.width, a.height );
 	crect = frect;
 	if ( a.map_state == IsUnmapped )
-	    setWFlags( WState_Visible );
-	else
 	    clearWFlags( WState_Visible );
+	else
+	    setWFlags( WState_Visible );
     }
 
     if ( destroyw )
@@ -342,7 +342,7 @@ bool QWidget::create()
 
 /*!
   Frees up window system resources.
-  Destroys the widget window if \a destroyWindow is TRUE.  
+  Destroys the widget window if \a destroyWindow is TRUE.
 
   destroy() calls itself recursively for all the child widgets,
   passing \a destroySubWindows for the \a destroyWindow parameter.
@@ -681,9 +681,9 @@ void QWidget::setIcon( const QPixmap &pixmap )
 	mask = pixmap.mask() ? *pixmap.mask() : pixmap.createHeuristicMask();
 	mask_pixmap = mask.handle();
     }
-    XWMHints *h = XGetWMHints( dpy, winId() );    
+    XWMHints *h = XGetWMHints( dpy, winId() );
     XWMHints  wm_hints;
-    bool got_hints = h != 0;     
+    bool got_hints = h != 0;
     if ( !got_hints ) {
 	h = &wm_hints;
 	h->flags = 0;
@@ -693,7 +693,7 @@ void QWidget::setIcon( const QPixmap &pixmap )
     h->flags |= IconPixmapHint | IconMaskHint;
     XSetWMHints( dpy, winId(), h );
     if ( got_hints )
-	XFree( h );
+	XFree( (char *)h );
 }
 
 
@@ -1138,6 +1138,10 @@ void QWidget::move( int x, int y )
 	return;
     QPoint p(x,y);
     QPoint oldp = pos();
+    if ( oldp == p ) {
+	internalMove( x, y );
+	return;
+    }
     QRect  r = frect;
     r.moveTopLeft( p );
     setFRect( r );
@@ -1191,6 +1195,8 @@ void QWidget::internalMove( int x, int y )
 
 void QWidget::resize( int w, int h )
 {
+    if ( isVisible() && (w == width() && h == height()) )
+	return;
     if ( testWFlags(WType_Desktop) )
 	return;
     if ( w < 1 )				// invalid size
@@ -1271,9 +1277,11 @@ void QWidget::setGeometry( int x, int y, int w, int h )
 	w = QMAX(w,extra->minw);
 	h = QMAX(h,extra->minh);
     }
-    QPoint oldp = frameGeometry().topLeft();
+    QPoint oldp = pos();
     QSize  olds = size();
     QRect  r( x, y, w, h );
+    if ( r.topLeft() == oldp && r.size() == olds )
+	return;
     setCRect( r );
     if ( !isVisible() ) {
 	deferMove( oldp );
@@ -1442,8 +1450,9 @@ void QWidget::erase( int x, int y, int w, int h )
   pixels downwards.  If \e dx/dy is negative, the scroll direction is
   leftwards/upwards.  Child widgets are moved accordingly.
 
-  The areas of the widget that are exposed will be erased and a
-  \link paintEvent() paint event\endlink will be generated.
+  The areas of the widget that are exposed will be erased and
+  \link paintEvent() paint events\endlink may be generated immediately,
+  or after some further event processing.
 
   \warning If you call scroll() in a function which may itself be
   called from the moveEvent() or paintEvent() of a direct child of the
