@@ -13,12 +13,12 @@ void yyerror( char *msg );
 
 #include "qlist.h"
 #include "qstring.h"
-#include "qdatetime.h"
+#include "qdatetm.h"
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 
-RCSTAG("$Id: moc.y,v 2.25 1998/07/06 19:22:17 hanord Exp $");
+RCSTAG("$Id: moc.y,v 2.18 1997/09/10 00:16:02 hanord Exp $");
 
 static QString rmWS( const char * );
 
@@ -29,10 +29,7 @@ struct Argument					/* single arg meta data*/
 {
     Argument( char *left, char *right )
 	{ leftType  = rmWS( left );
-	  rightType = rmWS( right );
-	  if ( leftType == "void" && rightType.isEmpty() )
-	      leftType = "";
-	}
+	  rightType = rmWS( right ); }
     QString leftType;
     QString rightType;
 };
@@ -98,7 +95,7 @@ QString	   tmpExpression;
 
 const int  formatRevision = 2;			/* moc output format revision*/
 
-#line 123 "moc.y"
+#line 120 "moc.y"
 typedef union {
     char	char_val;
     int		int_val;
@@ -109,7 +106,7 @@ typedef union {
     ArgList    *arg_list;
     Argument   *arg;
 } YYSTYPE;
-#line 113 "y.tab.c"
+#line 110 "y.tab.c"
 #define CHAR_VAL 257
 #define INT_VAL 258
 #define DOUBLE_VAL 259
@@ -851,7 +848,7 @@ YYSTYPE yylval;
 short yyss[YYSTACKSIZE];
 YYSTYPE yyvs[YYSTACKSIZE];
 #define yystacksize YYSTACKSIZE
-#line 760 "moc.y"
+#line 759 "moc.y"
 
 #if defined(_OS_WIN32_)
 #if defined(_CC_MSVC_)
@@ -881,7 +878,6 @@ QString	  className;				// name of parsed class
 QString	  superclassName;			// name of super class
 FuncList  signals;				// signal interface
 FuncList  slots;				// slots interface
-QDict<char> defines;				// simple #defines
 
 FILE  *out;					// output file
 
@@ -894,7 +890,6 @@ int main( int argc, char **argv )
     bool autoInclude = TRUE;
     char *error	     = 0;
     qtPath = "";
-
     for ( int n=1; n<argc && error==0; n++ ) {
 	QString arg = argv[n];
 	if ( arg[0] == '-' ) {			// option
@@ -911,13 +906,6 @@ int main( int argc, char **argv )
 	    } else if ( opt == "i" ) {		// no #include statement
 		noInclude   = TRUE;
 		autoInclude = FALSE;
-	    } else if ( opt[0] == 'D' ) {	// simple -DMACRO
-		int eq = opt.find('=');
-		if ( strlen(opt) > 1 && eq != 0 ) {
-		    defines.insert( opt.mid(1, eq < 0 ? 9999 : eq-1),
-				    qstrdup(eq < 0 ? "" :
-					    (const char*)opt.mid(eq,9999)) );
-		}
 	    } else if ( opt[0] == 'f' ) {	// produce #include statement
 		noInclude   = FALSE;
 		autoInclude = FALSE;
@@ -994,17 +982,16 @@ int main( int argc, char **argv )
 	if ( error )
 	    fprintf( stderr, "moc: %s\n", error );
 	fprintf( stderr, "Usage:  moc [options] <header-file>\n"
-		 "\t-D[macro] Define a macro (for #ifdef processing)\n"
-		 "\t-o file   Write output to file rather than stdout\n"
-		 "\t-i        Do not generate an #include statement\n"
-		 "\t-f[file]  Force #include, optional file name\n"
-		 "\t-p path   Path prefix for included file\n"
-		 "\t-k        Do not stop on errors\n"
-		 "\t-nw       Do not display warnings\n"
+		 "\t-o file  Write output to file rather than stdout\n"
+		 "\t-i       Do not generate an #include statement\n"
+		 "\t-f[file] Force #include, optional file name\n"
+		 "\t-p path  Path prefix for included file\n"
+		 "\t-k       Do not stop on errors\n"
+		 "\t-nw      Do not display warnings\n"
 #if 0
-		 "\t-ldbg     lex debug output\n"
-		 "\t-ydbg     yacc debug output\n"
-		 "\t-dbg      test parser, all non-signal members are slots\n"
+		 "\t-ldbg    lex debug output\n"
+		 "\t-ydbg    yacc debug output\n"
+		 "\t-dbg     test parser, all non-signal members are slots\n"
 #endif
 		 );
 	return 1;
@@ -1141,9 +1128,8 @@ void initClass()				 // prepare for new class
 //
 
 inline bool isIdentChar( char x )
-{						// Avoid bug in isalnum
-    return x == '_' || (x >= '0' && x <= '9') ||
-	 (x >= 'a' && x <= 'z') || (x >= 'A' && x <= 'Z');
+{
+    return isalnum(x) || x == '_';
 }
 
 inline bool isSpace( char x )
@@ -1325,12 +1311,10 @@ void generateFuncs( FuncList *list, char *functype, int num )
 	int count = 0;
 	Argument *a = f->args->first();
 	while ( a ) {
-	    if ( !a->leftType.isEmpty() || ! a->rightType.isEmpty() ) {
-		if ( count++ )
-		    typstr += ",";
-		typstr += a->leftType;
-		typstr += a->rightType;
-	    }
+	    if ( count++ )
+		typstr += ",";
+	    typstr += a->leftType;
+	    typstr += a->rightType;
 	    a = f->args->next();
 	}
 	fprintf( out, "    typedef %s(%s::*m%d_t%d)(%s)%s;\n",
@@ -1361,7 +1345,7 @@ void generateClass()		      // generate C++ source code for a class
     char *hdr1 = "/****************************************************************************\n"
 		 "** %s meta object code from reading C++ file '%s'\n**\n";
     char *hdr2 = "** Created: %s\n"
-		 "**      by: The Qt Meta Object Compiler ($Revision: 2.25 $)\n**\n";
+		 "**      by: The Qt Meta Object Compiler ($Revision: 2.18 $)\n**\n";
     char *hdr3 = "** WARNING! All changes made in this file will be lost!\n";
     char *hdr4 = "*****************************************************************************/\n\n";
     int   i;
@@ -1404,12 +1388,12 @@ void generateClass()		      // generate C++ source code for a class
 	fprintf( out, "#if !defined(Q_MOC_OUTPUT_REVISION)\n" );
 	fprintf( out, "#define Q_MOC_OUTPUT_REVISION %d\n", formatRevision );
 	fprintf( out, "#elif Q_MOC_OUTPUT_REVISION != %d\n", formatRevision );
-	fprintf( out, "#error \"Moc format conflict - "
-		 "please regenerate all moc files\"\n" );
+	fprintf( out, "#error Moc format conflict - "
+		 "please regenerate all moc files\n" );
 	fprintf( out, "#endif\n\n" );
 	if ( !noInclude )
 	    fprintf( out, "#include \"%s\"\n", (const char*)includeFile );
-	fprintf( out, "#include <%sqmetaobject.h>\n", (const char*)qtPath );
+	fprintf( out, "#include <%sqmetaobj.h>\n", (const char*)qtPath );
 	fprintf( out, "\n\n" );
     } else {
 	fprintf( out, "\n\n" );
@@ -1486,25 +1470,23 @@ void generateClass()		      // generate C++ source code for a class
 
 	i = 0;
 	while ( a ) {				// argument list
-	    if ( !a->leftType.isEmpty() || !a->rightType.isEmpty() ) {
-		if ( i ) {
-		    typstr += ",";
-		    valstr += ", ";
-		    argstr += ", ";
-		}
-		typstr += a->leftType;
-		typstr += a->rightType;
-		argstr += a->leftType;
-		argstr += " ";
-		sprintf( buf, "t%d", i );
-		valstr += buf;
-		argstr += buf;
-		argstr += a->rightType;
-		++i;
-		typvec[i] = typstr.copy();
-		valvec[i] = valstr.copy();
-		argvec[i] = argstr.copy();
+	    if ( i ) {
+		typstr += ",";
+		valstr += ", ";
+		argstr += ", ";
 	    }
+	    typstr += a->leftType;
+	    typstr += a->rightType;
+	    argstr += a->leftType;
+	    argstr += " ";
+	    sprintf( buf, "t%d", i );
+	    valstr += buf;
+	    argstr += buf;
+	    argstr += a->rightType;
+	    ++i;
+	    typvec[i] = typstr.copy();
+	    valvec[i] = valstr.copy();
+	    argvec[i] = argstr.copy();
 	    a = f->args->next();
 	}
 
@@ -1630,7 +1612,7 @@ void addMember( char m )
     tmpFunc  = new Function;
     CHECK_PTR( tmpFunc );
 }
-#line 1634 "y.tab.c"
+#line 1616 "y.tab.c"
 #define YYABORT goto yyabort
 #define YYREJECT goto yyabort
 #define YYACCEPT goto yyaccept
@@ -1772,463 +1754,463 @@ yyreduce:
     switch (yyn)
     {
 case 3:
-#line 221 "moc.y"
+#line 218 "moc.y"
 { initClass(); }
 break;
 case 4:
-#line 222 "moc.y"
+#line 219 "moc.y"
 { generateClass();
 						BEGIN OUTSIDE; }
 break;
 case 5:
-#line 229 "moc.y"
+#line 226 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 6:
-#line 230 "moc.y"
+#line 227 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 7:
-#line 234 "moc.y"
+#line 231 "moc.y"
 { yyval.string = stradd( yyvsp[-3].string, "<",
 				     tmpExpression =
 				     tmpExpression.stripWhiteSpace(), ">" ); }
 break;
 case 8:
-#line 245 "moc.y"
+#line 242 "moc.y"
 { initExpression();
 						    templLevel = 1;
 						    BEGIN IN_TEMPL_ARGS; }
 break;
 case 9:
-#line 258 "moc.y"
+#line 255 "moc.y"
 { initExpression();
 						    BEGIN IN_EXPR; }
 break;
 case 10:
-#line 264 "moc.y"
+#line 261 "moc.y"
 { yyval.string = ""; }
 break;
 case 11:
-#line 265 "moc.y"
+#line 262 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 12:
-#line 266 "moc.y"
+#line 263 "moc.y"
 { yyval.string = ""; }
 break;
 case 13:
-#line 267 "moc.y"
+#line 264 "moc.y"
 { skipFunc = TRUE; yyval.string = ""; }
 break;
 case 14:
-#line 268 "moc.y"
+#line 265 "moc.y"
 { skipFunc = TRUE; yyval.string = ""; }
 break;
 case 15:
-#line 272 "moc.y"
+#line 269 "moc.y"
 { yyval.string = straddSpc(yyvsp[-2].string,yyvsp[-1].string,yyvsp[0].string); }
 break;
 case 16:
-#line 275 "moc.y"
+#line 272 "moc.y"
 { yyval.string = ""; }
 break;
 case 17:
-#line 276 "moc.y"
+#line 273 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 18:
-#line 279 "moc.y"
+#line 276 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 19:
-#line 280 "moc.y"
+#line 277 "moc.y"
 { yyval.string = straddSpc(yyvsp[-1].string,yyvsp[0].string); }
 break;
 case 22:
-#line 285 "moc.y"
+#line 282 "moc.y"
 { skipFunc = TRUE; }
 break;
 case 26:
-#line 293 "moc.y"
+#line 290 "moc.y"
 { yyval.string = "const"; }
 break;
 case 27:
-#line 294 "moc.y"
+#line 291 "moc.y"
 { yyval.string = "volatile"; }
 break;
 case 28:
-#line 297 "moc.y"
+#line 294 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 29:
-#line 298 "moc.y"
+#line 295 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 30:
-#line 299 "moc.y"
+#line 296 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 31:
-#line 303 "moc.y"
+#line 300 "moc.y"
 { yyval.string = straddSpc(yyvsp[-1].string,yyvsp[0].string); }
 break;
 case 32:
-#line 304 "moc.y"
+#line 301 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 33:
-#line 306 "moc.y"
+#line 303 "moc.y"
 { yyval.string = "char"; }
 break;
 case 34:
-#line 307 "moc.y"
+#line 304 "moc.y"
 { yyval.string = "short"; }
 break;
 case 35:
-#line 308 "moc.y"
+#line 305 "moc.y"
 { yyval.string = "int"; }
 break;
 case 36:
-#line 309 "moc.y"
+#line 306 "moc.y"
 { yyval.string = "long"; }
 break;
 case 37:
-#line 310 "moc.y"
+#line 307 "moc.y"
 { yyval.string = "signed"; }
 break;
 case 38:
-#line 311 "moc.y"
+#line 308 "moc.y"
 { yyval.string = "unsigned"; }
 break;
 case 39:
-#line 312 "moc.y"
+#line 309 "moc.y"
 { yyval.string = "float"; }
 break;
 case 40:
-#line 313 "moc.y"
+#line 310 "moc.y"
 { yyval.string = "double"; }
 break;
 case 41:
-#line 314 "moc.y"
+#line 311 "moc.y"
 { yyval.string = "void"; }
 break;
 case 42:
-#line 318 "moc.y"
+#line 315 "moc.y"
 { yyval.string = stradd( "template<",
 				     tmpExpression =
 				     tmpExpression.stripWhiteSpace(), ">" ); }
 break;
 case 44:
-#line 324 "moc.y"
+#line 321 "moc.y"
 { templateClass = TRUE; }
 break;
 case 45:
-#line 328 "moc.y"
+#line 325 "moc.y"
 { yyval.string = "class"; }
 break;
 case 46:
-#line 329 "moc.y"
+#line 326 "moc.y"
 { yyval.string = "struct"; }
 break;
 case 47:
-#line 332 "moc.y"
+#line 329 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 48:
-#line 334 "moc.y"
+#line 331 "moc.y"
 { yyval.string = stradd( "::", yyvsp[0].string ); }
 break;
 case 49:
-#line 338 "moc.y"
+#line 335 "moc.y"
 { yyval.string = stradd( yyvsp[-2].string, "::", yyvsp[0].string );}
 break;
 case 50:
-#line 339 "moc.y"
+#line 336 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 51:
-#line 343 "moc.y"
+#line 340 "moc.y"
 { yyval.string = straddSpc(yyvsp[-1].string,yyvsp[0].string); }
 break;
 case 52:
-#line 344 "moc.y"
+#line 341 "moc.y"
 { yyval.string = stradd("enum ",yyvsp[0].string); }
 break;
 case 53:
-#line 345 "moc.y"
+#line 342 "moc.y"
 { yyval.string = stradd("union ",yyvsp[0].string); }
 break;
 case 54:
-#line 350 "moc.y"
+#line 347 "moc.y"
 { yyval.arg_list = yyvsp[-1].arg_list;}
 break;
 case 55:
-#line 351 "moc.y"
+#line 348 "moc.y"
 { yyval.arg_list = yyvsp[-2].arg_list;
 				       moc_warn("Ellipsis not supported"
 					       " in signals and slots.\n"
 					       "Ellipsis argument ignored."); }
 break;
 case 56:
-#line 357 "moc.y"
+#line 354 "moc.y"
 { yyval.arg_list = tmpArgList; }
 break;
 case 57:
-#line 358 "moc.y"
+#line 355 "moc.y"
 { yyval.arg_list = yyvsp[0].arg_list; }
 break;
 case 59:
-#line 362 "moc.y"
+#line 359 "moc.y"
 { moc_warn("Ellipsis not supported"
 					       " in signals and slots.\n"
 					       "Ellipsis argument ignored."); }
 break;
 case 60:
-#line 370 "moc.y"
+#line 367 "moc.y"
 { yyval.arg_list = addArg(yyvsp[0].arg); }
 break;
 case 61:
-#line 371 "moc.y"
+#line 368 "moc.y"
 { yyval.arg_list = addArg(yyvsp[0].arg); }
 break;
 case 62:
-#line 374 "moc.y"
+#line 371 "moc.y"
 { yyval.arg = new Argument(straddSpc(yyvsp[-1].string,yyvsp[0].string),"");
 				  CHECK_PTR(yyval.arg); }
 break;
 case 63:
-#line 377 "moc.y"
+#line 374 "moc.y"
 { expLevel = 1; }
 break;
 case 64:
-#line 379 "moc.y"
+#line 376 "moc.y"
 { yyval.arg = new Argument(straddSpc(yyvsp[-4].string,yyvsp[-3].string),"");
 				  CHECK_PTR(yyval.arg); }
 break;
 case 65:
-#line 383 "moc.y"
+#line 380 "moc.y"
 { yyval.arg = new Argument(straddSpc(yyvsp[-3].string,yyvsp[-2].string),yyvsp[0].string);
 				  CHECK_PTR(yyval.arg); }
 break;
 case 66:
-#line 387 "moc.y"
+#line 384 "moc.y"
 { expLevel = 1; }
 break;
 case 67:
-#line 389 "moc.y"
+#line 386 "moc.y"
 { yyval.arg = new Argument(straddSpc(yyvsp[-6].string,yyvsp[-5].string),yyvsp[-3].string);
 				  CHECK_PTR(yyval.arg); }
 break;
 case 68:
-#line 394 "moc.y"
+#line 391 "moc.y"
 { yyval.string = ""; }
 break;
 case 69:
-#line 395 "moc.y"
+#line 392 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 70:
-#line 399 "moc.y"
+#line 396 "moc.y"
 { yyval.string = straddSpc(yyvsp[-1].string,yyvsp[0].string); }
 break;
 case 71:
-#line 400 "moc.y"
+#line 397 "moc.y"
 { expLevel = 1; }
 break;
 case 72:
-#line 402 "moc.y"
+#line 399 "moc.y"
 { yyval.string = stradd( "[",
 				     tmpExpression =
 				     tmpExpression.stripWhiteSpace(), "]" ); }
 break;
 case 73:
-#line 405 "moc.y"
+#line 402 "moc.y"
 { expLevel = 1; }
 break;
 case 74:
-#line 407 "moc.y"
+#line 404 "moc.y"
 { yyval.string = stradd( yyvsp[-4].string,"[",
 				     tmpExpression =
 				     tmpExpression.stripWhiteSpace(),"]" ); }
 break;
 case 75:
-#line 410 "moc.y"
+#line 407 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 76:
-#line 411 "moc.y"
+#line 408 "moc.y"
 { yyval.string = yyvsp[-1].string; }
 break;
 case 77:
-#line 414 "moc.y"
+#line 411 "moc.y"
 { yyval.string = ""; }
 break;
 case 78:
-#line 416 "moc.y"
+#line 413 "moc.y"
 { yyval.string = straddSpc(yyvsp[-1].string,yyvsp[0].string);}
 break;
 case 79:
-#line 417 "moc.y"
+#line 414 "moc.y"
 { expLevel = 1; }
 break;
 case 80:
-#line 419 "moc.y"
+#line 416 "moc.y"
 { yyval.string = stradd( yyvsp[-4].string,"[",
 				     tmpExpression =
 				     tmpExpression.stripWhiteSpace(),"]" ); }
 break;
 case 81:
-#line 422 "moc.y"
+#line 419 "moc.y"
 { yyval.string = yyvsp[-1].string; }
 break;
 case 83:
-#line 433 "moc.y"
+#line 430 "moc.y"
 { tmpFunc->args	     = yyvsp[-3].arg_list;
 						  tmpFunc->qualifier = yyvsp[-1].string; }
 break;
 case 85:
-#line 439 "moc.y"
+#line 436 "moc.y"
 { func_warn("Variable as signal or slot."); }
 break;
 case 86:
-#line 440 "moc.y"
+#line 437 "moc.y"
 { expLevel=0; }
 break;
 case 87:
-#line 442 "moc.y"
+#line 439 "moc.y"
 { skipFunc = TRUE; }
 break;
 case 88:
-#line 443 "moc.y"
+#line 440 "moc.y"
 { expLevel=0; }
 break;
 case 89:
-#line 445 "moc.y"
+#line 442 "moc.y"
 { skipFunc = TRUE; }
 break;
 case 90:
-#line 449 "moc.y"
+#line 446 "moc.y"
 { expLevel = 1; }
 break;
 case 92:
-#line 451 "moc.y"
+#line 448 "moc.y"
 { expLevel = 1; }
 break;
 case 94:
-#line 456 "moc.y"
+#line 453 "moc.y"
 { yyval.string = ""; }
 break;
 case 95:
-#line 457 "moc.y"
+#line 454 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 96:
-#line 460 "moc.y"
+#line 457 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 97:
-#line 461 "moc.y"
+#line 458 "moc.y"
 { yyval.string = straddSpc(yyvsp[-1].string,yyvsp[0].string);}
 break;
 case 98:
-#line 464 "moc.y"
+#line 461 "moc.y"
 { yyval.string = straddSpc("*",yyvsp[0].string);}
 break;
 case 99:
-#line 465 "moc.y"
+#line 462 "moc.y"
 { yyval.string = stradd("&",yyvsp[0].string);}
 break;
 case 100:
-#line 472 "moc.y"
+#line 469 "moc.y"
 { yyval.string = ""; }
 break;
 case 101:
-#line 473 "moc.y"
+#line 470 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 102:
-#line 476 "moc.y"
+#line 473 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 103:
-#line 478 "moc.y"
+#line 475 "moc.y"
 { yyval.string = straddSpc(yyvsp[-1].string,yyvsp[0].string); }
 break;
 case 104:
-#line 481 "moc.y"
+#line 478 "moc.y"
 { yyval.string = "const"; }
 break;
 case 105:
-#line 482 "moc.y"
+#line 479 "moc.y"
 { yyval.string = "volatile"; }
 break;
 case 109:
-#line 490 "moc.y"
+#line 487 "moc.y"
 {BEGIN IN_FCT; fctLevel = 1;}
 break;
 case 110:
-#line 491 "moc.y"
+#line 488 "moc.y"
 {BEGIN QT_DEF; }
 break;
 case 111:
-#line 498 "moc.y"
+#line 495 "moc.y"
 { BEGIN IN_CLASS; level = 1; }
 break;
 case 112:
-#line 500 "moc.y"
+#line 497 "moc.y"
 { BEGIN QT_DEF; }
 break;
 case 113:
-#line 501 "moc.y"
+#line 498 "moc.y"
 { BEGIN QT_DEF;	  /* -- " -- */
 						  skipClass = TRUE; }
 break;
 case 114:
-#line 505 "moc.y"
+#line 502 "moc.y"
 { BEGIN QT_DEF; /* catch ';' */
 						  skipClass = TRUE; }
 break;
 case 115:
-#line 507 "moc.y"
+#line 504 "moc.y"
 { skipClass = TRUE;
 						  BEGIN GIMME_SEMICOLON; }
 break;
 case 121:
-#line 519 "moc.y"
+#line 516 "moc.y"
 { className = yyvsp[0].string; }
 break;
 case 122:
-#line 520 "moc.y"
+#line 517 "moc.y"
 { superclassName = yyvsp[0].string; }
 break;
 case 123:
-#line 523 "moc.y"
+#line 520 "moc.y"
 { yyval.string = 0; }
 break;
 case 124:
-#line 524 "moc.y"
+#line 521 "moc.y"
 { yyval.string = yyvsp[0].string; }
 break;
 case 129:
-#line 536 "moc.y"
+#line 533 "moc.y"
 { tmpAccessPerm = yyvsp[0].access; }
 break;
 case 130:
-#line 537 "moc.y"
+#line 534 "moc.y"
 { moc_err( "Missing access specifier"
 						   " before \"slots:\"." ); }
 break;
 case 131:
-#line 541 "moc.y"
+#line 538 "moc.y"
 { BEGIN QT_DEF; }
 break;
 case 133:
-#line 543 "moc.y"
+#line 540 "moc.y"
 { BEGIN QT_DEF; }
 break;
 case 135:
-#line 545 "moc.y"
+#line 542 "moc.y"
 { if ( tmpAccessPerm )
 				moc_warn("Q_OBJECT is not in the private"
 					" section of the class.\n"
@@ -2237,20 +2219,22 @@ case 135:
 						  Q_OBJECTdetected = TRUE; }
 break;
 case 136:
-#line 553 "moc.y"
+#line 550 "moc.y"
 { moc_err( "Signals cannot "
 						 "have access specifiers" ); }
 break;
 case 138:
-#line 556 "moc.y"
+#line 553 "moc.y"
 { if ( grammarDebug )
 						  BEGIN QT_DEF;
 					      else
 						  BEGIN IN_CLASS;
+					   if ( level != 1 )
+					       moc_warn( "unexpected ':'" );
 					 }
 break;
 case 140:
-#line 562 "moc.y"
+#line 561 "moc.y"
 { BEGIN IN_CLASS;
 					   if ( level != 1 )
 					       moc_warn( "unexpected access"
@@ -2258,84 +2242,84 @@ case 140:
 					 }
 break;
 case 145:
-#line 578 "moc.y"
+#line 577 "moc.y"
 { addMember('s'); }
 break;
 case 150:
-#line 589 "moc.y"
+#line 588 "moc.y"
 { addMember('t'); }
 break;
 case 153:
-#line 596 "moc.y"
+#line 595 "moc.y"
 { yyval.string=yyvsp[0].string; }
 break;
 case 156:
-#line 604 "moc.y"
+#line 603 "moc.y"
 { yyval.string = stradd( yyvsp[-3].string, "(", yyvsp[-1].string, ")" ); }
 break;
 case 157:
-#line 606 "moc.y"
+#line 605 "moc.y"
 { yyval.string = stradd( yyvsp[-3].string, "(", yyvsp[-1].string, ")" ); }
 break;
 case 158:
-#line 609 "moc.y"
+#line 608 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 159:
-#line 610 "moc.y"
+#line 609 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 160:
-#line 611 "moc.y"
+#line 610 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 161:
-#line 612 "moc.y"
+#line 611 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 162:
-#line 613 "moc.y"
+#line 612 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 163:
-#line 614 "moc.y"
+#line 613 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 164:
-#line 615 "moc.y"
+#line 614 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 165:
-#line 616 "moc.y"
+#line 615 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 166:
-#line 617 "moc.y"
+#line 616 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 167:
-#line 618 "moc.y"
+#line 617 "moc.y"
 {yyval.string=yyvsp[0].string;}
 break;
 case 168:
-#line 621 "moc.y"
+#line 620 "moc.y"
 { yyval.access=_PRIVATE; }
 break;
 case 169:
-#line 622 "moc.y"
+#line 621 "moc.y"
 { yyval.access=_PROTECTED; }
 break;
 case 170:
-#line 623 "moc.y"
+#line 622 "moc.y"
 { yyval.access=_PUBLIC; }
 break;
 case 214:
-#line 675 "moc.y"
+#line 674 "moc.y"
 { tmpFunc->type = yyvsp[-1].string;
 						  tmpFunc->name = yyvsp[0].string; }
 break;
 case 215:
-#line 678 "moc.y"
+#line 677 "moc.y"
 { tmpFunc->type = "int";
 						  tmpFunc->name = yyvsp[0].string;
 				  if ( tmpFunc->name == className )
@@ -2344,14 +2328,14 @@ case 215:
 						}
 break;
 case 216:
-#line 685 "moc.y"
+#line 684 "moc.y"
 {
 				       func_warn( "Destructors cannot be"
 						  " signals or slots.");
 						}
 break;
 case 217:
-#line 691 "moc.y"
+#line 690 "moc.y"
 {   
 						    char *tmp = 
 							straddSpc(yyvsp[-4].string,yyvsp[-3].string,yyvsp[-2].string,yyvsp[-1].string);
@@ -2360,75 +2344,75 @@ case 217:
 						    tmpFunc->name = yyvsp[0].string; }
 break;
 case 218:
-#line 698 "moc.y"
+#line 697 "moc.y"
 { skipFunc = TRUE; }
 break;
 case 219:
-#line 700 "moc.y"
+#line 699 "moc.y"
 { tmpFunc->type =
 						      straddSpc(yyvsp[-2].string,yyvsp[-1].string);
 						  tmpFunc->name = yyvsp[0].string; }
 break;
 case 220:
-#line 705 "moc.y"
+#line 704 "moc.y"
 { tmpFunc->type =
 						      straddSpc(yyvsp[-3].string,yyvsp[-2].string,yyvsp[-1].string);
 						  tmpFunc->name = yyvsp[0].string; }
 break;
 case 221:
-#line 709 "moc.y"
+#line 708 "moc.y"
 { operatorError();    }
 break;
 case 222:
-#line 711 "moc.y"
+#line 710 "moc.y"
 { operatorError();    }
 break;
 case 223:
-#line 714 "moc.y"
+#line 713 "moc.y"
 { operatorError();    }
 break;
 case 224:
-#line 716 "moc.y"
+#line 715 "moc.y"
 { operatorError();    }
 break;
 case 225:
-#line 719 "moc.y"
+#line 718 "moc.y"
 { operatorError();    }
 break;
 case 227:
-#line 724 "moc.y"
+#line 723 "moc.y"
 { func_warn("Variable as signal or slot."); }
 break;
 case 228:
-#line 727 "moc.y"
+#line 726 "moc.y"
 { func_warn("Variable as signal or slot."); }
 break;
 case 229:
-#line 729 "moc.y"
+#line 728 "moc.y"
 { func_warn("Enum declaration as signal or"
 					  " slot."); }
 break;
 case 233:
-#line 739 "moc.y"
+#line 738 "moc.y"
 { expLevel = 0; }
 break;
 case 235:
-#line 741 "moc.y"
+#line 740 "moc.y"
 { expLevel = 0; }
 break;
 case 238:
-#line 746 "moc.y"
+#line 745 "moc.y"
 { expLevel = 0; }
 break;
 case 240:
-#line 751 "moc.y"
+#line 750 "moc.y"
 {BEGIN IN_FCT; fctLevel=1;}
 break;
 case 241:
-#line 752 "moc.y"
+#line 751 "moc.y"
 {BEGIN QT_DEF; }
 break;
-#line 2432 "y.tab.c"
+#line 2416 "y.tab.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
