@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qdstream.h,v 2.0 1996/09/24 10:16:09 agulbra Exp $
+** $Id: qdstream.h,v 2.2 1997/08/06 15:05:51 hanord Exp $
 **
 ** Definition of QDataStream class
 **
@@ -7,13 +7,16 @@
 **
 ** Copyright (C) 1992-1997 Troll Tech AS.  All rights reserved.
 **
-** This file is part of the non-commercial distribution of Qt 1.2.
+** This file is part of the free edition of Qt 1.33.
 **
 ** See the file LICENSE included in the distribution for the usage
 ** and distribution terms, or http://www.troll.no/qt/license.html.
 **
-** (This file differs from the one in the commercial distribution of
-** Qt only by this comment.)
+** IMPORTANT NOTE: You may NOT copy this file or any part of it into
+** your own programs or libraries.
+**
+** (This file differs from the one in the commercial edition of Qt
+** only by this comment.)
 **
 *****************************************************************************/
 
@@ -45,22 +48,22 @@ public:
     bool	 isPrintableData() const;
     void	 setPrintableData( bool );
 
-    QDataStream &operator>>( INT8 &i );
-    QDataStream &operator>>( UINT8 &i );
-    QDataStream &operator>>( INT16 &i );
-    QDataStream &operator>>( UINT16 &i );
-    QDataStream &operator>>( INT32 &i );
-    QDataStream &operator>>( UINT32 &i );
+    QDataStream &operator>>( Q_INT8 &i );
+    QDataStream &operator>>( Q_UINT8 &i );
+    QDataStream &operator>>( Q_INT16 &i );
+    QDataStream &operator>>( Q_UINT16 &i );
+    QDataStream &operator>>( Q_INT32 &i );
+    QDataStream &operator>>( Q_UINT32 &i );
     QDataStream &operator>>( float &f );
     QDataStream &operator>>( double &f );
     QDataStream &operator>>( char *&str );
 
-    QDataStream &operator<<( INT8 i );
-    QDataStream &operator<<( UINT8 i );
-    QDataStream &operator<<( INT16 i );
-    QDataStream &operator<<( UINT16 i );
-    QDataStream &operator<<( INT32 i );
-    QDataStream &operator<<( UINT32 i );
+    QDataStream &operator<<( Q_INT8 i );
+    QDataStream &operator<<( Q_UINT8 i );
+    QDataStream &operator<<( Q_INT16 i );
+    QDataStream &operator<<( Q_UINT16 i );
+    QDataStream &operator<<( Q_INT32 i );
+    QDataStream &operator<<( Q_UINT32 i );
     QDataStream &operator<<( float f );
     QDataStream &operator<<( double f );
     QDataStream &operator<<( const char *str );
@@ -103,23 +106,23 @@ inline bool QDataStream::isPrintableData() const
 inline void QDataStream::setPrintableData( bool p )
 { printable = p; }
 
-inline QDataStream &QDataStream::operator>>( UINT8 &i )
-{ return *this >> (INT8&)i; }
+inline QDataStream &QDataStream::operator>>( Q_UINT8 &i )
+{ return *this >> (Q_INT8&)i; }
 
-inline QDataStream &QDataStream::operator>>( UINT16 &i )
-{ return *this >> (INT16&)i; }
+inline QDataStream &QDataStream::operator>>( Q_UINT16 &i )
+{ return *this >> (Q_INT16&)i; }
 
-inline QDataStream &QDataStream::operator>>( UINT32 &i )
-{ return *this >> (INT32&)i; }
+inline QDataStream &QDataStream::operator>>( Q_UINT32 &i )
+{ return *this >> (Q_INT32&)i; }
 
-inline QDataStream &QDataStream::operator<<( UINT8 i )
-{ return *this << (INT8)i; }
+inline QDataStream &QDataStream::operator<<( Q_UINT8 i )
+{ return *this << (Q_INT8)i; }
 
-inline QDataStream &QDataStream::operator<<( UINT16 i )
-{ return *this << (INT16)i; }
+inline QDataStream &QDataStream::operator<<( Q_UINT16 i )
+{ return *this << (Q_INT16)i; }
 
-inline QDataStream &QDataStream::operator<<( UINT32 i )
-{ return *this << (INT32)i; }
+inline QDataStream &QDataStream::operator<<( Q_UINT32 i )
+{ return *this << (Q_INT32)i; }
 
 
 #endif // QDSTREAM_H
