@@ -1,5 +1,5 @@
 /**********************************************************************
-** $Id: qlistbox.cpp,v 2.49 1997/10/07 14:24:15 agulbra Exp $
+** $Id: qlistbox.cpp,v 2.49.2.2 1997/11/24 12:16:47 paul Exp $
 **
 ** Implementation of QListBox widget class
 **
@@ -7,7 +7,7 @@
 **
 ** Copyright (C) 1992-1997 Troll Tech AS.  All rights reserved.
 **
-** This file is part of the free edition of Qt 1.31.
+** This file is part of the free edition of Qt 1.33.
 **
 ** See the file LICENSE included in the distribution for the usage
 ** and distribution terms, or http://www.troll.no/qt/license.html.
@@ -28,7 +28,7 @@
 #include "qpixmap.h"
 #include "qapp.h"
 
-RCSTAG("$Id: qlistbox.cpp,v 2.49 1997/10/07 14:24:15 agulbra Exp $");
+RCSTAG("$Id: qlistbox.cpp,v 2.49.2.2 1997/11/24 12:16:47 paul Exp $");
 
 Q_DECLARE(QListM, QListBoxItem);
 
@@ -443,12 +443,21 @@ QListBox::QListBox( QWidget *parent, const char *name, WFlags f )
     }
 }
 
+
+#if QT_VERSION == 200
+#error "Remove QListBox pointer."
+#endif
+
+static QListBox * changedListBox = 0;
+
 /*!
   Destroys the list box.  Deletes all list box items.
 */
 
 QListBox::~QListBox()
 {
+    if ( changedListBox == this )
+	changedListBox = 0;
     goingDown = TRUE;
     clearList();
     if ( qlb_maxLenDict )
@@ -1850,15 +1859,6 @@ void QListBox::clearSelection()
     }
 }
 
-    
-    
-
-#if QT_VERSION == 200
-#error "Remove QListBox pointer."
-#endif
-
-static QListBox * changedListBox = 0;
-
 /*!  If \a lazy is FALSE, maybe emit the changed() signal.  If \a lazy
   is TRUE, note that it's to be sent out at some later time.
 */
