@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qmenubar.cpp,v 2.37 1997/10/09 14:11:53 agulbra Exp $
+** $Id: qmenubar.cpp,v 2.37.2.1 1998/01/13 17:38:28 agulbra Exp $
 **
 ** Implementation of QMenuBar class
 **
@@ -7,7 +7,7 @@
 **
 ** Copyright (C) 1992-1997 Troll Tech AS.  All rights reserved.
 **
-** This file is part of the free edition of Qt 1.31.
+** This file is part of the free edition of Qt 1.33.
 **
 ** See the file LICENSE included in the distribution for the usage
 ** and distribution terms, or http://www.troll.no/qt/license.html.
@@ -28,7 +28,7 @@
 #include "qapp.h"
 #include <ctype.h>
 
-RCSTAG("$Id: qmenubar.cpp,v 2.37 1997/10/09 14:11:53 agulbra Exp $");
+RCSTAG("$Id: qmenubar.cpp,v 2.37.2.1 1998/01/13 17:38:28 agulbra Exp $");
 
 
 /*!
@@ -139,7 +139,7 @@ QMenuBar::QMenuBar( QWidget *parent, const char *name )
     if ( gs == WindowsStyle ) {
 	h = 2 + fm.height() + motifItemVMargin + 2*motifBarFrame;
     } else {
-	h =  motifBarFrame + motifBarVMargin + fm.height() 
+	h =  motifBarFrame + motifBarVMargin + fm.height()
 	    + motifItemVMargin + 2*motifBarFrame + 2*motifItemFrame;
     }
 
@@ -221,7 +221,7 @@ void QMenuBar::menuInsPopup( QPopupMenu *popup )
 
 void QMenuBar::menuDelPopup( QPopupMenu *popup )
 {
-    popup->parentMenu = this;
+    popup->parentMenu = 0;
     popup->disconnect( SIGNAL(activatedRedirect(int)), this,
 		       SLOT(subActivated(int)) );
     popup->disconnect( SIGNAL(highlightedRedirect(int)), this,
@@ -254,10 +254,10 @@ bool QMenuBar::eventFilter( QObject *object, QEvent *event )
 	return FALSE;
     }
 
-    if ( style() != WindowsStyle || 
+    if ( style() != WindowsStyle ||
 	 !isVisibleToTLW() ||
 	 !object->isWidgetType() ||
-	 !( event->type() == Event_Accel || 
+	 !( event->type() == Event_Accel ||
 	    event->type() == Event_KeyPress ||
 	    event->type() == Event_KeyRelease ) )
 	return FALSE;
@@ -717,7 +717,7 @@ void QMenuBar::drawContents( QPainter *p )
 		g = palette().normal();
 	    else
 		g = palette().disabled();
-		     
+		
 	    if ( gs == WindowsStyle ) {
 		p->fillRect( r, palette().normal().background() );
 		if ( i == actItem ) {
@@ -937,7 +937,7 @@ void QMenuBar::keyPressEvent( QKeyEvent *e )
 	    else if ( i < 0 )
 		i = c - 1;
 	    mi = mitems->at( i );
-	    // ### fix windows-style traversal - currently broken due to 
+	    // ### fix windows-style traversal - currently broken due to
 	    // QMenuBar's reliance on QPopupMenu
 	    if ( /* (style() == WindowsStyle || */ mi->isEnabled() /* ) */
 		 && !mi->isSeparator() )
@@ -1001,7 +1001,7 @@ void QMenuBar::resizeEvent( QResizeEvent *e )
     QSize oldSize = e->oldSize();
     QSize newSize = e->size();
     if(oldSize == newSize) return;
-  
+
     badSize = TRUE;
     calculateRects();
 }
@@ -1055,7 +1055,7 @@ void QMenuBar::setWindowsAltMode( bool enable, int index )
     if ( enable ) {
 	if ( !windowsaltactive ) {
 	    windowsaltactive = 1;
-	    if ( style() == WindowsStyle ) 
+	    if ( style() == WindowsStyle )
 		setFocus();
 	}
 	if ( index == actItem ) // work around setActItem overoptimization
