@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qtooltip.cpp,v 2.33 1997/08/26 16:45:03 agulbra Exp $
+** $Id: qtooltip.cpp,v 2.33.2.1 1997/11/18 12:40:13 agulbra Exp $
 **
 ** Tool Tips (or Balloon Help) for any widget or rectangle
 **
 ** Copyright (C) 1992-1997 Troll Tech AS.  All rights reserved.
 **
-** This file is part of the free edition of Qt 1.31.
+** This file is part of the free edition of Qt 1.33.
 **
 ** See the file LICENSE included in the distribution for the usage
 ** and distribution terms, or http://www.troll.no/qt/license.html.
@@ -23,7 +23,7 @@
 #include "qptrdict.h"
 #include "qapp.h"
 
-RCSTAG("$Id: qtooltip.cpp,v 2.33 1997/08/26 16:45:03 agulbra Exp $");
+RCSTAG("$Id: qtooltip.cpp,v 2.33.2.1 1997/11/18 12:40:13 agulbra Exp $");
 
 // Magic value meaning an entire widget - if someone tries to insert a
 // tool tip on this part of a widget it will be interpreted as the
@@ -94,7 +94,7 @@ private:
 ** QTipManager meta object code from reading C++ file 'qtooltip.cpp'
 **
 ** Created: Mon Mar 17 12:39:34 1997
-**      by: The Qt Meta Object Compiler ($Revision: 2.33 $)
+**      by: The Qt Meta Object Compiler ($Revision: 2.33.2.1 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -233,6 +233,7 @@ void QTipManager::add( QWidget *w, const QRect &r, const char *s,
     t->group = g;
 
     tips->insert( w, t );
+    connect( w, SIGNAL(destroyed()), this, SLOT(clientWidgetDestroyed()) );
     if ( a ) {
 	showTip();
 	tips->take( w );
@@ -357,7 +358,7 @@ bool QTipManager::eventFilter( QObject *obj, QEvent *e )
     while( w && !t ) {
 	t = (*tips)[ w ];
 	if ( !t )
-	    w = w->parentWidget();
+	    w = w->testWFlags(WType_TopLevel) ? 0 : w->parentWidget();
     }
 
     if ( !t ) {
